@@ -34,9 +34,10 @@
 
 
 /* Convert integer status into a string error code */
-void checkStatus(int status,
-                 char* status_str,
-                 int status_len)
+void C_checkStatus(
+    int status,
+    char* status_str,
+    int status_len)
 {
 
   status_len = status_len>1000?1000:status_len;
@@ -78,11 +79,12 @@ void checkStatus(int status,
 
 
 /* Function to de-nagle a TCP socket connection */
-void setTCPNoDelay(int *socket,
-                     int* flag,
-                     int* status,
-                     char** status_str,
-                     int* status_len)
+void C_setTCPNoDelay(
+    int *socket,
+    int* flag,
+    int* status,
+    char** status_str,
+    int* status_len)
 {
   int off;
 
@@ -98,7 +100,43 @@ void setTCPNoDelay(int *socket,
                        );
 
 
-  checkStatus(errno, status_str[0], *status_len);
-
+  C_checkStatus(errno, status_str[0], *status_len);
+  
   return;
 }
+
+/* function to check socket options */
+/* NOT USED...
+void C_getsockopt(int *s,
+                  int *level,
+                  int *optname,
+                  int *optval,
+                  int *optlen,
+                  int *status,
+                  char *status_str,
+                  int *status_len)
+{
+  *status = getsockopt(*s, *level, *optname, optval, optlen);
+
+  C_checkStatus(*status, status_str, *status_len);
+  
+}
+*/
+
+/* function to set socket options */
+/* NOT USED ...
+void C_setsockopt(int *s,
+                  int *level,
+                  int *optname,
+                  int *optval,
+                  int *optlen,
+                  int *status,
+                  char *status_str,
+                  int *status_len)
+{
+
+  *status = setsockopt(*s, *level,  *optname, optval, *optlen);
+
+  C_checkStatus(*status, status_str, *status_len);
+}
+*/
